Registry Management
===================

Omniduct provides some simple tooling to help manage ensembles of `Duct`
configurations. The primary tool is the `DuctRegistry`, which manages
`Duct` instances and allows them to communicate with each other.

For some simple examples on its use, please refer to the :doc:`/quickstart`.

.. automodule:: omniduct.registry
    :members:
    :special-members: __init__
    :show-inheritance:
    :member-order: bysource
